@@ -68,9 +68,10 @@ def test_all_cam_models_can_run(numpy_image, batch_size, width, height,
                      use_cuda=False)
     cam.batch_size = 4
     if target_category is None:
-      targets = None
+        targets = None
     else:
-      targets = [ClassifierOutputTarget(target_category) for _ in range(batch_size)]
+        targets = [ClassifierOutputTarget(target_category)
+                   for _ in range(batch_size)]
 
     grayscale_cam = cam(input_tensor=input_tensor,
                         targets=targets,
